@@ -53,6 +53,7 @@ import org.opennms.netmgt.xml.eventconf.AlarmData;
 import org.opennms.netmgt.xml.eventconf.LogDestType;
 import org.opennms.netmgt.xml.eventconf.Logmsg;
 import org.opennms.web.api.Util;
+import org.opennms.web.services.EventConfProgrammaticService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.InitializingBean;
@@ -88,7 +89,7 @@ public class ThresholdController extends AbstractController implements Initializ
 
     private EventConfDao m_eventConfDao;
 
-    private boolean eventConfChanged = false;
+    private EventConfProgrammaticService eventConfProgrammaticService;
 
     @Autowired
     private WriteableThresholdingDao thresholdingDao;
@@ -519,17 +520,6 @@ public class ThresholdController extends AbstractController implements Initializ
         } catch (Throwable e) {
             throw new ServletException("Could not save the changes to the threshold because " + e.getMessage(), e);
         }
-
-        if (eventConfChanged) {
-            try {
-                m_eventConfDao.saveCurrent();
-                sendNotifEvent(createEventBuilder(EventConstants.EVENTSCONFIG_CHANGED_EVENT_UEI).getEvent());
-            } catch (Throwable e) {
-                throw new ServletException("Could not save the changes to the event configuration because " + e.getMessage(), e);
-            }
-            eventConfChanged = false;
-        }
-
     }
 
     private ModelAndView deleteThreshold(String thresholdIndexString, String groupName) throws ServletException {
@@ -583,6 +573,13 @@ public class ThresholdController extends AbstractController implements Initializ
         else {
             baseDef.setDsLabel(dsLabel);
         }
+        String exprLabel = request.getParameter("exprLabel");
+        if (exprLabel == null || "".equals(exprLabel)) {
+            baseDef.setExprLabel(null);
+        }
+        else {
+            baseDef.setExprLabel(exprLabel);
+        }
 
         String description = request.getParameter("description");
         if (description == null || "".equals(description)) {
@@ -701,8 +698,9 @@ public class ThresholdController extends AbstractController implements Initializ
                     event.setAlarmData(alarmData);
                 }
             }
-            m_eventConfDao.addEventToProgrammaticStore(event);
-            eventConfChanged = true;
+            // Save the event to DB
+            eventConfProgrammaticService.saveEventToDB(event, "Web UI");
+            eventConfProgrammaticService.reloadEventsFromDB();
         }
     }
 
@@ -863,4 +861,13 @@ public class ThresholdController extends AbstractController implements Initializ
         m_eventConfDao = eventConfDao;
     }
 
+    /**
+     * <p>setEventConfProgrammaticService</p>
+     *
+     * @param eventConfProgrammaticService a {@link EventConfProgrammaticService} object.
+     */
+    public void setEventConfProgrammaticService(EventConfProgrammaticService eventConfProgrammaticService) {
+        this.eventConfProgrammaticService = eventConfProgrammaticService;
+    }
+
 }
